\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{adcaij}
\LoadClass{article}

\RequirePackage[sc]{mathpazo}
\RequirePackage[T1]{fontenc}
\RequirePackage{lmodern}
\RequirePackage{microtype}
\RequirePackage{graphicx}
%\RequirePackage[authoryear]{natbib}
%\RequirePackage{natbib}
%\let\bibhang\relax
\usepackage{fancyhdr}
    \renewcommand{\headrulewidth}{0pt}
	\pagestyle{fancy}
	
\RequirePackage{apalike}
\RequirePackage{multicol}
\righthyphenmin=62
\lefthyphenmin=62
%\AtEndDocument{\end{multicol}}
%Style fonts
\newcommand{\titlefont}{\normalfont\rmfamily\bfseries\fontsize{20}{40}\selectfont}
\renewcommand{\rmdefault}{ptm}

% ------
% Page layout
\usepackage[font=it]{caption}
\usepackage{paralist}
%\usepackage{fontspec}
%\setmainfont{Times New Roman}
%\newfontfamily\calibrifont{Calibri}


\renewcommand{\baselinestretch}{1} %to get "1" line spacing. This works fine.
\newcommand{\numberofjournal}{1}


% ------
% Titling (section/subsection)
\usepackage{titlesec}
\renewcommand\thesection{\arabic{section}}
\titleformat{\section}[block]{\large\scshape\centering}{\thesection.}{0.5em}{}
\titleformat{\subsection}
{\normalfont\large\bfseries}{\thesubsection}{0.5em}{}
\titleformat{\subsubsection}
{\normalfont\normalsize\bfseries}{\thesubsubsection}{0.5em}{}
\titleformat{\paragraph}[runin]
{\normalfont\normalsize\bfseries}{\theparagraph}{0.5em}{}
\titleformat{\subparagraph}[runin]
{\normalfont\normalsize\bfseries}{\thesubparagraph}{0.5em}{}

\newtoks\titlerunning
\newtoks\authorruning
%\newcommand{\email}[1]{\normalfont{#1}}
\let\@email\relax
\def\email#1{\def\@email{#1}}

%Titling (maketitle)
\renewcommand{\maketitle}{%

\begin{@twocolumnfalse}
\fontsize{20}{12}\normalfont\rmfamily\fontseries{b}\selectfont
\begin{minipage}{2cm}
\includegraphics[width=2cm]{logo.png}
\end{minipage}
\begin{minipage}{13cm}
\setlength\lineskip{3pt}
\begin{flushright}
\@title
\end{flushright}

\vspace{-0.4ex} 
\@author
 \vspace{0ex} 
\@email
  \end{minipage}
 \end{@twocolumnfalse}
 %\twocolumn[\@maketitle]%

}

% ------
% Clickable URLs (optional)
\usepackage[hidelinks]{hyperref}

% ------
% Header/footer

\setlength{\headwidth}{15.5cm}
	%Headings, please fill the fields with the name of the authors and the title
\let\@titlerunning\relax
\def\titlerunning#1{\def\@titlerunning{#1}}

\let\@authorrunning\relax
\def\authorrunning#1{\def\@authorrunning{#1}}
\rhead{\fontsize{8}{8}\sffamily\@titlerunning}
\lhead{\fontsize{8}{8}\sffamily\@authorrunning}

	\rfoot{ \fontsize{8}{8}\sffamily\smallskip ADCAIJ, Regular Issue \numberofjournal \\ \vskip3pt http://adcaij.usal.es}
	\cfoot{\fontsize{8}{8}\sffamily \smallskip \includegraphics[width=0.5cm]{logo-page.png} \smallskip \medskip \\ \thepage}
	\lfoot{\fontsize{8}{8}\sffamily \smallskip Advances in Distributed Computing and \\ \vskip3pt Artificial Intelligence Journal \\ \vskip3pt \textcopyright Ediciones Universidad de Salamanca / cc by-nc-nd}

\usepackage{authblk}
\setlength{\affilsep}{0.1ex}
\renewcommand\Authfont{\normalfont\rmfamily\fontsize{14}{17}\selectfont}
\renewcommand\Affilfont{\normalfont\rmfamily\fontsize{8}{11}\selectfont}


\usepackage{titlesec}

\titleformat*{\section}{\fontsize{16}{16}\normalfont\rmfamily\fontseries{b}}
\titleformat*{\subsection}{\fontsize{14}{14}\normalfont\rmfamily\fontseries{b}}
\titleformat*{\subsubsection}{\large\normalfont\rmfamily\fontseries{b}}
\titleformat*{\paragraph}{\large\bfseries}
\titleformat*{\subparagraph}{\large\bfseries}


% ------
% Abstract
\usepackage{abstract}
	\renewcommand{\abstractnamefont}{\normalfont\itshape}
	\renewcommand{\abstracttextfont}{\normalfont\small\itshape}


\renewcommand{\abstractname}{ABSTRACT}
\newcommand{\keywordname}{KEYWORD}

%Stablish our keyword box
\newbox\keybox
\def\keyword{%
  \def\sep{\unskip}%
 \def\MSC{\@ifnextchar[{\@MSC}{\@MSC[2000]}}
  \def\@MSC[##1]{\par\leavevmode\hbox {\it ##1~MSC:\space}}%
  \def\PACS{\par\leavevmode\hbox {\it PACS:\space}}%
  \def\JEL{\par\leavevmode\hbox {\it JEL:\space}}%
  \global\setbox\keybox=\vbox\bgroup\hsize=3cm
   \normalfont\def\baselinestretch{1}
  \parskip\z@
  \normalfont\rmfamily\itshape{ }
  \raggedright                         % Keywords are not justified.
  \ignorespaces}
\def\endkeyword{\par \egroup}

%Renew abstract environment with keywords included.
\renewenvironment{abstract} {\fontsize{10}{10}\normalfont\rmfamily\vskip10pt\noindent 
\begin{@twocolumnfalse}
\begin{minipage}{4cm}
	\hskip0.5cm\keywordname
\end{minipage}
\begin{minipage}{14cm}
	\abstractname
\end{minipage}
%\vskip1pt
\rule{\linewidth}{0.4pt}
\vskip6pt
\begin{minipage}{3cm}
\vspace*{-2.5cm}
	\ifvoid\keybox\else\unvbox\keybox \fi 
\vspace*{\fill}
\end{minipage}
\begin{minipage}{12cm}  \parindent4pt \itshape   }{\hfil \end{minipage}\normalsize
\vskip6pt \hskip-0.5cm
\rule{\linewidth}{.4pt}\vskip24pt\end{@twocolumnfalse}}


%\newcommand{\bibliostyle}{
%\onecolumn
%
%\begin{minipage}{15cm}
%\begin{multicol}{1}
%}

\makeatletter
\@ifundefined{chapter}{\def\thebibliography#1{\section{References\@mkboth
  {REFERENCES}{REFERENCES}}\list
  {\relax}{\setlength{\labelsep}{0em}
	\setlength{\itemindent}{-\bibhang}
    \itemsep\z@skip\parsep\z@skip
	\setlength{\leftmargin}{\bibhang}}
    \def\newblock{\hskip .11em plus .33em minus .07em}
    \sloppy\clubpenalty4000\widowpenalty4000
    \sfcode`\.=1000\relax}}%
{\def\thebibliography#1{\chapter*{Bibliography\@mkboth
  {BIBLIOGRAPHY}{BIBLIOGRAPHY}}\list
  {\relax}{\setlength{\labelsep}{0em}
	\setlength{\itemindent}{-\bibhang}
    \itemsep\z@skip\parsep\z@skip
	\setlength{\leftmargin}{\bibhang}}
    \def\newblock{\hskip .11em plus .33em minus .07em}
    \sloppy\clubpenalty4000\widowpenalty4000
    \sfcode`\.=1000\relax}}
\makeatother

\usepackage[hmarginratio=1:1,top=60mm,left=30mm,bottom=50mm,right=30mm,columnsep=20pt]{geometry}